@@ -8,9 +8,9 @@ from typing import Callable, Tuple, Union
 import numpy as np
 import pandas as pd
 import pyabc
-
+import petab_MS.problem as problem
 from ..model import MorpheusModel, MorpheusModels
-
+from ..sumstat.base import SummaryStatistics as SumStat
 logger = logging.getLogger("FitMultiCell.PEtab_MS")
 try:
     import petab_MS
@@ -77,6 +77,11 @@ class PetabImporter:
         """
         return create_prior(parameter_df=self.petab_problem.parameter_df)
 
+    def get_objective_function(self) -> Callable:
+
+        return get_objective_function(
+            objective_function_callable=self.petab_problem.objective_callable)
+
     def get_par_map(self) -> dict:
         """Create parameter map to be use with the Morpheus model.
         Returns
@@ -213,18 +218,19 @@ def create_model(importer, executable):
     par_scale = importer.petab_problem.get_optimization_parameter_scales()
     if 'observableFormula' in importer.petab_problem.observable_df:
 
-        ss_post_process_callable = get_ss_post_process(
+        summary_statistics_callable = get_summary_statistics(
             importer.petab_problem.observable_df,
             os.path.dirname(importer.petab_problem.model_file),
         )
-
+    # in case of no conditions are defined
     if cond_status == "no_condition":
         if executable is not None:
             model_con1 = MorpheusModel(
                 importer.petab_problem.model_file,
                 par_map=par_map_imported,
                 par_scale=par_scale,
-                ss_post_processing=ss_post_process_callable,
+                sumstat=SumStat(
+                    sum_stat_calculator=summary_statistics_callable),
                 executable=executable,
             )
         else:
@@ -232,9 +238,12 @@ def create_model(importer, executable):
                 importer.petab_problem.model_file,
                 par_map=par_map_imported,
                 par_scale=par_scale,
-                ss_post_processing=ss_post_process_callable,
+                sumstat=SumStat(
+                    sum_stat_calculator=summary_statistics_callable),
             )
         return model_con1
+
+    # in case of only one condition is defined
     elif cond_status == "one_condition":
         exp_cond_imported = importer.get_exp_cond_map()
         if executable is not None:
@@ -243,7 +252,7 @@ def create_model(importer, executable):
                 par_map=par_map_imported,
                 exp_cond_map={'condition1': exp_cond_imported['condition1']},
                 par_scale=par_scale,
-                ss_post_processing=ss_post_process_callable,
+                sumstat=SumStat(sum_stat_calculator=summary_statistics_callable),
                 executable=executable,
             )
         else:
@@ -252,9 +261,10 @@ def create_model(importer, executable):
                 par_map=par_map_imported,
                 exp_cond_map={'condition1': exp_cond_imported['condition1']},
                 par_scale=par_scale,
-                ss_post_processing=ss_post_process_callable,
+                sumstat=SumStat(sum_stat_calculator=summary_statistics_callable),
             )
         return model_con1
+    # in case of multiple conditions are defined
     else:
         exp_cond_imported = importer.get_exp_cond_map()
         models_list = []
@@ -265,9 +275,11 @@ def create_model(importer, executable):
                     par_map=par_map_imported,
                     exp_cond_map={cond_key: cond_val},
                     par_scale=par_scale,
-                    ss_post_processing=ss_post_process_callable,
+                    sumstat=SumStat(
+                        sum_stat_calculator=summary_statistics_callable),
                     executable=executable,
                 )
+                models_list.append(tmp_model)
         else:
             for cond_key, cond_val in exp_cond_imported.items():
                 tmp_model = MorpheusModel(
@@ -275,12 +287,13 @@ def create_model(importer, executable):
                     par_map=par_map_imported,
                     exp_cond_map={cond_key: cond_val},
                     par_scale=par_scale,
-                    ss_post_processing=ss_post_process_callable,
+                    sumstat=SumStat(
+                        sum_stat_calculator=summary_statistics_callable),
                 )
 
-            models_list.append(tmp_model)
+                models_list.append(tmp_model)
 
-        return MorpheusModels(models_list=models_list)
+        return MorpheusModels(models=models_list)
 
 
 def create_prior(parameter_df: pd.DataFrame) -> pyabc.Distribution:
@@ -322,7 +335,7 @@ def create_prior(parameter_df: pd.DataFrame) -> pyabc.Distribution:
             lb, ub = prior_pars
             lb, ub = float(lb), float(ub)
             # scipy pars are location, width
-            rv = pyabc.RV('uniform', loc=lb, scale=ub - lb)
+            rv = pyabc.RV('uniform', lb, ub - lb)
         elif prior_type in [C.PARAMETER_SCALE_NORMAL, C.NORMAL]:
             mean, std = prior_pars
             mean, std = float(mean), float(std)
@@ -364,6 +377,19 @@ def create_prior(parameter_df: pd.DataFrame) -> pyabc.Distribution:
     return prior
 
 
+def get_objective_function(objective_function_callable: problem) -> Callable:
+    """get the objective function to be used to evaluate the discrepancy
+    between the simulated and the measured data.
+    Parameters
+    ----------
+    objective_function_callable: The PEtab objective function Callable.
+    Returns
+    -------
+    obj_func: A Callable to the objection function.
+    """
+    return objective_function_callable
+
+
 def get_par_map(parameter_df: pd.DataFrame) -> dict:
     """Create parameter map to be use with the Morpheus model.
     Parameters
@@ -426,29 +452,29 @@ def get_scales(parameter_df: pd.DataFrame) -> Tuple[dict, dict]:
     return prior_scales, scaled_scales
 
 
-def get_ss_post_process(
+def get_summary_statistics(
     observable_df: pd.DataFrame, problem_path
 ) -> Union[Callable, dict]:
-    """Create a callable for the post processing function for observables.
+    """Create a callable for the summary statistics function for observables.
 
     Parameters
     ----------
     observable_df: The PEtab observable data frame.
-    model_file: The model path
+    problem_path: The problem path
     Returns
     -------
-    ss_post_process_dict: A Callable or dictionary of callable for each
+    summary_statistics_dict: A Callable or dictionary of callable for each
     summary statistics.
     """
 
     module_path = observable_df.observableFormula.to_dict()
-    post_processing_ss_dict = {}
+    summary_statistics_dict = {}
     for key, path in module_path.items():
         head, tail = os.path.split(path)
 
         if head != '':
             raise ValueError(
-                f"ss_post_process function should be within the "
+                f"summary_statistics function should be within the "
                 f"Petab folder. However, now it is on: {head}."
             )
         tail_info = tuple(val for val in tail.split(';'))
@@ -460,8 +486,10 @@ def get_ss_post_process(
         sys.modules[spec.name] = module
         spec.loader.exec_module(module)
         new_module = getattr(module, tail_info[1])
-        post_processing_ss_dict[key] = new_module
-    return post_processing_ss_dict
+        summary_statistics_dict[key] = new_module
+    if summary_statistics_dict == {}:
+        summary_statistics_dict = None
+    return summary_statistics_dict
 
 
 # def import_petab_problem(
