@@ -4,10 +4,10 @@ from typing import List
 import numpy as np
 
 from ..util import tsv_to_df
-from .base import SumstatFun
+from .base import SummaryStatistics
 
 
-class ClusterCountSumstatFun(SumstatFun):
+class ClusterCountSumstatFun(SummaryStatistics):
     """
     Total number of clusters for all time points.
     """
@@ -429,7 +429,7 @@ def check_for_connecting_cluster_loop(
     return index_list_of_cluster
 
 
-class ClusterSizeSumstatFun(SumstatFun):
+class ClusterSizeSumstatFun(SummaryStatistics):
     """
     Total number of clusters and size of each cluster.
     """
@@ -524,7 +524,7 @@ def get_clusters_sizes_tp(
     return dict_cluster_member
 
 
-class CCNonContributorsTpSumstatFun(SumstatFun):
+class CCNonContributorsTpSumstatFun(SummaryStatistics):
     """
     List of inactive cell in the grid at a specific time point.
     """
@@ -615,7 +615,7 @@ def get_cc_non_contributors_tp(
     return inactive_cell_list
 
 
-class CCContributorsAllTpCountSumstatFun(SumstatFun):
+class CCContributorsAllTpCountSumstatFun(SummaryStatistics):
     """
     Total number of active infected cells in the grid at a
     specific time point.
